==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/PRICINGSCHEDULEWOCRITERIAID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PRICINGSCHEDULEWOCRITERIAID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PRICINGSCHEDULEWOCRITERIAID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICINGSCHEDULEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCLASSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRICINGSCHEDULEWOCRITERIAID_Type", propOrder = {
    "pricingscheduleid",
    "departmentid",
    "workordertype",
    "equipmentclassid"
})
public class PRICINGSCHEDULEWOCRITERIAID_Type {

    @XmlElement(name = "PRICINGSCHEDULEID", required = true)
    protected PRICINGSCHEDULEID_Type pricingscheduleid;
    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "WORKORDERTYPE", required = true)
    protected TYPE_Type workordertype;
    @XmlElement(name = "EQUIPMENTCLASSID", required = true)
    protected CLASSID_Type equipmentclassid;

    /**
     * Obtient la valeur de la propriété pricingscheduleid.
     * 
     * @return
     *     possible object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public PRICINGSCHEDULEID_Type getPRICINGSCHEDULEID() {
        return pricingscheduleid;
    }

    /**
     * Définit la valeur de la propriété pricingscheduleid.
     * 
     * @param value
     *     allowed object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public void setPRICINGSCHEDULEID(PRICINGSCHEDULEID_Type value) {
        this.pricingscheduleid = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété workordertype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWORKORDERTYPE() {
        return workordertype;
    }

    /**
     * Définit la valeur de la propriété workordertype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWORKORDERTYPE(TYPE_Type value) {
        this.workordertype = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentclassid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getEQUIPMENTCLASSID() {
        return equipmentclassid;
    }

    /**
     * Définit la valeur de la propriété equipmentclassid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setEQUIPMENTCLASSID(CLASSID_Type value) {
        this.equipmentclassid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/PRICINGSCHEDULEWOCRITERIAID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PRICINGSCHEDULEWOCRITERIAID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PRICINGSCHEDULEWOCRITERIAID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICINGSCHEDULEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCLASSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRICINGSCHEDULEWOCRITERIAID_Type", propOrder = {
    "pricingscheduleid",
    "departmentid",
    "workordertype",
    "equipmentclassid"
})
public class PRICINGSCHEDULEWOCRITERIAID_Type {

    @XmlElement(name = "PRICINGSCHEDULEID", required = true)
    protected PRICINGSCHEDULEID_Type pricingscheduleid;
    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "WORKORDERTYPE", required = true)
    protected TYPE_Type workordertype;
    @XmlElement(name = "EQUIPMENTCLASSID", required = true)
    protected CLASSID_Type equipmentclassid;

    /**
     * Gets the value of the pricingscheduleid property.
     * 
     * @return
     *     possible object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public PRICINGSCHEDULEID_Type getPRICINGSCHEDULEID() {
        return pricingscheduleid;
    }

    /**
     * Sets the value of the pricingscheduleid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public void setPRICINGSCHEDULEID(PRICINGSCHEDULEID_Type value) {
        this.pricingscheduleid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the workordertype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWORKORDERTYPE() {
        return workordertype;
    }

    /**
     * Sets the value of the workordertype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWORKORDERTYPE(TYPE_Type value) {
        this.workordertype = value;
    }

    /**
     * Gets the value of the equipmentclassid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getEQUIPMENTCLASSID() {
        return equipmentclassid;
    }

    /**
     * Sets the value of the equipmentclassid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setEQUIPMENTCLASSID(CLASSID_Type value) {
        this.equipmentclassid = value;
    }

}
